/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context;

import net.craftforge.essential.core.constants.HttpStatusCode;

import java.io.OutputStream;
import java.util.Map;

/**
 * A request provides a standard way to access HTTP response data
 * data used by different contexts (e.g. servlet response).
 *
 * @author Christian Bick
 * @since 20.02.2011
 */
public interface Response {

    /**
     * Sends the response headers and sets the HTTP response status.
     * Must be called prior to <code>getBodyStream();</code>
     *
     * @param status The response status
     * @param headers The response headers
     */
    public void sendHeaders(HttpStatusCode status, Map<String, String[]> headers);

    /**
     * Gets the HTTP status code of this response.
     *
     * @return The HTTP status code
     */
    public HttpStatusCode getStatusCode();

    /**
     * Gets the HTTP headers of this response.
     *
     * @return The HTTP headers
     */
    public Map<String, String[]> getHeaders();

    /**
     * Gets the output stream for streaming the response body.
     *
     * @return The body output stream
     */
    public OutputStream getBodyOutputStream();

}
