/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.basic;

import net.craftforge.commons.collections.CaseInsensitiveMap;
import net.craftforge.essential.context.Request;

import java.io.InputStream;
import java.util.Map;

/**
 * A basic implementation of a request.
 *
 * @author Christian Bick
 * @since 20.06.11
 */
public class BasicRequest implements Request {

    private String httpMethod;
    private String urlResourcePart;
    private Map<String, String[]> requestHeaders;
    private Map<String, String[]> requestParameters;
    private InputStream inputStream;

    public BasicRequest(
            String httpMethod,
            String urlResourcePart,
            Map<String, String[]> requestHeaders,
            Map<String, String[]> requestParameters,
            InputStream inputStream) {

        this.httpMethod = httpMethod;
        this.urlResourcePart = urlResourcePart;
        this.requestHeaders = new CaseInsensitiveMap<String[]>();
        this.requestHeaders.putAll(requestHeaders);
        this.requestParameters = requestParameters;
        this.inputStream = inputStream;
    }

    /**
     * {@inheritDoc}
     */
    public String getHttpMethod() {
        return httpMethod;
    }

    /**
     * {@inheritDoc}
     */
    public String getUrlResourcePart() {
        return urlResourcePart;
    }

    /**
     * {@inheritDoc}
     */
    public Map<String, String[]> getHeaders() {
        return requestHeaders;
    }

    /**
     * {@inheritDoc}
     */
    public Map<String, String[]> getParameters() {
        return requestParameters;
    }

    /**
     * {@inheritDoc}
     */
    public InputStream getBodyInputStream() {
        return inputStream;
    }
}
