/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.servlet;

import net.craftforge.essential.context.Context;

import javax.inject.Inject;
import javax.servlet.ServletContext;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Implementation of a context for servlet containers. Uses
 * the {@link ServletContext} as source of context information.
 *
 * @author Christian Bick
 * @since 26.12.11
 */
public class ServletWebContext implements Context {

    private ServletContext context;

    private Map<String, String> initParameters;

    @Inject
    public ServletWebContext(ServletContext context) {
        this.context = context;
    }

    /**
     * {@inheritDoc}
     */
    @SuppressWarnings("unchecked")
    public Map<String, String> getInitParameters() {
        if (initParameters != null) {
            return initParameters;
        }
        initParameters = new HashMap<String, String>();
        for (String paramName : (List<String>)Collections.list(context.getInitParameterNames())) {
            initParameters.put(paramName, context.getInitParameter(paramName));
        }
        return initParameters;
    }
}
