/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller;

import net.craftforge.essential.controller.phases.flow.PhaseFlow;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.inject.Inject;

/**
 * A controller performs a request.
 *
 * @author Christian Bick
 * @since 02.12.2010
 */
public class Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(Controller.class);

    private PhaseFlow phaseFlow;

    @Inject
    public Controller(PhaseFlow phaseFlow) {
        this.phaseFlow = phaseFlow;
    }

    /**
     * Performs a controller request.
     *
     * @throws ControllerException if performing the request failed
     * @return The resulting HTTP status code
     */
    public int perform() throws ControllerException {
        try {
            LOGGER.info("[Performing request]");

            ControllerState state = new ControllerState();
            ControllerPhase phase = phaseFlow.getFirstPhase();
            while (phase != null) {
                LOGGER.debug("[Running phase] {}", phase.getClass().getName());
                phase.run(state);
                phase = phaseFlow.getPhaseAfter(phase, state);
            }

            LOGGER.info("[Successfully performed request]");
            return state.getStatus().getCode();
        } catch (RuntimeException e) {
            throw new ControllerException("An internal error occurred", e);
        }
    }
}
