/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller.injection;

import net.craftforge.essential.context.Context;
import net.craftforge.essential.controller.allocation.ResourceTree;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.inject.Inject;
import javax.inject.Provider;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

/**
 * @author Christian Bick
 * @since 02.12.11
 */
public class ResourceTreeProvider implements Provider<ResourceTree> {

    private static final Logger LOGGER = LoggerFactory.getLogger(ResourceTreeProvider.class);

    private static ConcurrentMap<String, ResourceTree> instances = new ConcurrentHashMap<String, ResourceTree>();

    private String resourcePackage;

    @Inject
    public ResourceTreeProvider (Context context) {
        this.resourcePackage = context.getInitParameters().get("resourcePackage");
    }

    public ResourceTree get() {
        if (! instances.containsKey(resourcePackage)) {
            LOGGER.info("[Resource tree initialization] {} ", resourcePackage);
            instances.putIfAbsent(resourcePackage, new ResourceTree(resourcePackage));
        }
        return instances.get(resourcePackage);
    }
}
