/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller.phases;

import net.craftforge.essential.controller.ControllerConfiguration;
import net.craftforge.essential.controller.ControllerException;
import net.craftforge.essential.controller.ControllerPhase;
import net.craftforge.essential.controller.ControllerState;
import net.craftforge.essential.controller.handlers.AuthenticationHandler;
import net.craftforge.essential.core.constants.HttpStatusCode;

import javax.inject.Inject;

/**
 * Authenticates the requester via HTTP basic authorization.
 *
 * @author Christian Bick
 * @since 22.05.2011
 */
public class AuthenticationPhase implements ControllerPhase {

    private ControllerConfiguration configuration;

    @Inject
    public AuthenticationPhase(ControllerConfiguration configuration) {
        this.configuration = configuration;
    }

    /**
     * {@inheritDoc}
     */
    public void run(ControllerState state) throws ControllerException {
        Class<?> handlerClass = configuration.getAuthenticationHandler();
        if (handlerClass == null ) {
            return;
        }

        AuthenticationHandler handler;
        try {
            handler = (AuthenticationHandler)handlerClass.newInstance();
        } catch (InstantiationException e) {
            throw new ControllerException("The authentication handler class specified in the controller" +
                    " configuration could not be instantiated: " + handlerClass.getName(), e);
        } catch (IllegalAccessException e) {
            throw new ControllerException("The authentication handler class specified in the controller" +
                    " configuration could not be instantiated: " + handlerClass.getName(), e);
        }
        if (! handler.authenticate()) {
            throw new ControllerException("Authentication failed because the user does not exist or" +
                    " user and password do not match", HttpStatusCode.Unauthorized);
        }
    }
}
