/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller.phases;

import net.craftforge.essential.controller.ControllerConfiguration;
import net.craftforge.essential.controller.ControllerException;
import net.craftforge.essential.controller.ControllerPhase;
import net.craftforge.essential.controller.ControllerState;
import net.craftforge.essential.controller.documentation.jaxb.WadlApplication;
import net.craftforge.essential.controller.managers.DocumentationManager;
import net.craftforge.essential.controller.resolvers.UrlResolver;
import net.craftforge.essential.core.constants.HttpStatusCode;

import javax.inject.Inject;

/**
 * Generates the documentation of the resource class and sets it as the result.
 *
 * @author Christian Bick
 * @since 20.07.11
 */
public class DocumentationPhase implements ControllerPhase {

    private ControllerConfiguration configuration;
    private DocumentationManager documentationManager;
    private UrlResolver urlResolver;

    @Inject
    public DocumentationPhase(ControllerConfiguration configuration, DocumentationManager documentationManager,
                              UrlResolver urlResolver) {
        this.configuration = configuration;
        this.documentationManager = documentationManager;
        this.urlResolver = urlResolver;
    }

    /**
     * {@inheritDoc}
     */
    public void run(ControllerState state) throws ControllerException {
        WadlApplication application = documentationManager.getDocumentation(urlResolver.getResourcePart(), configuration);
        state.setStatus(HttpStatusCode.OK);
        state.setResult(application);
    }

}
