/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller.resolvers;

import java.io.UnsupportedEncodingException;

/**
 * A charset resolver extracts the content charset and
 * accepted charset from an HTTP request.
 *
 * @author Christian Bick
 * @since 28.11.11
 */
public interface CharsetResolver {

    /**
     * Gets the charset of the body content.
     *
     * @return The content charset
     */
    String getContentCharset();

    /**
     * Gets a charset accepted by the client.
     *
     * @return The accepted charset
     * @throws UnsupportedEncodingException if none of the accepted charset encodings is supported.
     */
    String getAcceptedCharset() throws UnsupportedEncodingException;
}
