/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.controller.resolvers;

import net.craftforge.essential.context.Request;
import net.craftforge.essential.core.utils.UriUtils;

import javax.inject.Inject;

/**
 * {@inheritDoc}
 *
 * @author Christian Bick
 * @since 28.11.11
 */
public class DefaultUrlResolver implements UrlResolver {

    private Request request;

    @Inject
    public DefaultUrlResolver(Request request) {
        this.request = request;
    }

    /**
     * {@inheritDoc}
     *
     * Removes the meta data part from the URL info part. This is everything in
     * the URL info part from the beginning until the first occurring dot
     * (excluded). (my/path.put.xml -> my/path)
     *
     * @return The request URL resource part
     */
    public String getResourcePart() {
        String pathInfo = request.getUrlResourcePart();
        if (pathInfo.contains(".")) {
            pathInfo = pathInfo.substring(0, pathInfo.indexOf("."));
        }
        return UriUtils.standardPath(pathInfo);
    }

    /**
     * {@inheritDoc}
     *
     * This is everything in the URL info part from the first occurring dot
     * (included) till the end. (my/path.put.xml -> .put.xml)
     *
     * @return The request URL meta part
     */
    public String getMetaPart() {
        String pathInfo = request.getUrlResourcePart();
        if (! pathInfo.contains(".")) {
            return "";
        }
        return pathInfo.substring(pathInfo.indexOf(".") - 1, pathInfo.length());
    }

}
